==> istio-model-v1beta1-6.7.1-sources.jar: io/fabric8/istio/api/networking/v1beta1/WorkloadEntrySpecBuilder.java <==
package io.fabric8.istio.api.networking.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class WorkloadEntrySpecBuilder extends WorkloadEntrySpecFluentImpl<WorkloadEntrySpecBuilder> implements VisitableBuilder<WorkloadEntrySpec,WorkloadEntrySpecBuilder>{
  public WorkloadEntrySpecBuilder() {
    this(false);
  }
  public WorkloadEntrySpecBuilder(Boolean validationEnabled) {
    this(new WorkloadEntrySpec(), validationEnabled);
  }
  public WorkloadEntrySpecBuilder(WorkloadEntrySpecFluent<?> fluent) {
    this(fluent, false);
  }
  public WorkloadEntrySpecBuilder(WorkloadEntrySpecFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new WorkloadEntrySpec(), validationEnabled);
  }
  public WorkloadEntrySpecBuilder(WorkloadEntrySpecFluent<?> fluent,WorkloadEntrySpec instance) {
    this(fluent, instance, false);
  }
  public WorkloadEntrySpecBuilder(WorkloadEntrySpecFluent<?> fluent,WorkloadEntrySpec instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    if (instance != null) {
      fluent.withAddress(instance.getAddress());
      fluent.withLabels(instance.getLabels());
      fluent.withLocality(instance.getLocality());
      fluent.withNetwork(instance.getNetwork());
      fluent.withPorts(instance.getPorts());
      fluent.withServiceAccount(instance.getServiceAccount());
      fluent.withWeight(instance.getWeight());
    }
    this.validationEnabled = validationEnabled; 
  }
  public WorkloadEntrySpecBuilder(WorkloadEntrySpec instance) {
    this(instance,false);
  }
  public WorkloadEntrySpecBuilder(WorkloadEntrySpec instance,Boolean validationEnabled) {
    this.fluent = this; 
    if (instance != null) {
      this.withAddress(instance.getAddress());
      this.withLabels(instance.getLabels());
      this.withLocality(instance.getLocality());
      this.withNetwork(instance.getNetwork());
      this.withPorts(instance.getPorts());
      this.withServiceAccount(instance.getServiceAccount());
      this.withWeight(instance.getWeight());
    }
    this.validationEnabled = validationEnabled; 
  }
  WorkloadEntrySpecFluent<?> fluent;
  Boolean validationEnabled;
  public WorkloadEntrySpec build() {
    WorkloadEntrySpec buildable = new WorkloadEntrySpec(fluent.getAddress(),fluent.getLabels(),fluent.getLocality(),fluent.getNetwork(),fluent.getPorts(),fluent.getServiceAccount(),fluent.getWeight());
    return buildable;
  }
  
}

==> istio-model-v1beta1-6.8.1-sources.jar: io/fabric8/istio/api/networking/v1beta1/WorkloadEntrySpecBuilder.java <==
package io.fabric8.istio.api.networking.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class WorkloadEntrySpecBuilder extends WorkloadEntrySpecFluent<WorkloadEntrySpecBuilder> implements VisitableBuilder<WorkloadEntrySpec,WorkloadEntrySpecBuilder>{
  public WorkloadEntrySpecBuilder() {
    this(false);
  }
  public WorkloadEntrySpecBuilder(Boolean validationEnabled) {
    this(new WorkloadEntrySpec(), validationEnabled);
  }
  public WorkloadEntrySpecBuilder(WorkloadEntrySpecFluent<?> fluent) {
    this(fluent, false);
  }
  public WorkloadEntrySpecBuilder(WorkloadEntrySpecFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new WorkloadEntrySpec(), validationEnabled);
  }
  public WorkloadEntrySpecBuilder(WorkloadEntrySpecFluent<?> fluent,WorkloadEntrySpec instance) {
    this(fluent, instance, false);
  }
  public WorkloadEntrySpecBuilder(WorkloadEntrySpecFluent<?> fluent,WorkloadEntrySpec instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    instance = (instance != null ? instance : new WorkloadEntrySpec());

    if (instance != null) {
      fluent.withAddress(instance.getAddress());
      fluent.withLabels(instance.getLabels());
      fluent.withLocality(instance.getLocality());
      fluent.withNetwork(instance.getNetwork());
      fluent.withPorts(instance.getPorts());
      fluent.withServiceAccount(instance.getServiceAccount());
      fluent.withWeight(instance.getWeight());
      fluent.withAddress(instance.getAddress());
      fluent.withLabels(instance.getLabels());
      fluent.withLocality(instance.getLocality());
      fluent.withNetwork(instance.getNetwork());
      fluent.withPorts(instance.getPorts());
      fluent.withServiceAccount(instance.getServiceAccount());
      fluent.withWeight(instance.getWeight());
    }
    this.validationEnabled = validationEnabled; 
  }
  public WorkloadEntrySpecBuilder(WorkloadEntrySpec instance) {
    this(instance,false);
  }
  public WorkloadEntrySpecBuilder(WorkloadEntrySpec instance,Boolean validationEnabled) {
    this.fluent = this; 
    instance = (instance != null ? instance : new WorkloadEntrySpec());

    if (instance != null) {
      this.withAddress(instance.getAddress());
      this.withLabels(instance.getLabels());
      this.withLocality(instance.getLocality());
      this.withNetwork(instance.getNetwork());
      this.withPorts(instance.getPorts());
      this.withServiceAccount(instance.getServiceAccount());
      this.withWeight(instance.getWeight());
      this.withAddress(instance.getAddress());
      this.withLabels(instance.getLabels());
      this.withLocality(instance.getLocality());
      this.withNetwork(instance.getNetwork());
      this.withPorts(instance.getPorts());
      this.withServiceAccount(instance.getServiceAccount());
      this.withWeight(instance.getWeight());
    }
    this.validationEnabled = validationEnabled; 
  }
  WorkloadEntrySpecFluent<?> fluent;
  Boolean validationEnabled;
  public WorkloadEntrySpec build() {
    WorkloadEntrySpec buildable = new WorkloadEntrySpec(fluent.getAddress(),fluent.getLabels(),fluent.getLocality(),fluent.getNetwork(),fluent.getPorts(),fluent.getServiceAccount(),fluent.getWeight());
    return buildable;
  }
  
}
